@@ -1,5 +1,4 @@
-#define USE_POSIX_SIGNALS
-#define USE_POSIX_TIME
+/* $PostgreSQL: pgsql/src/include/port/dgux.h,v 1.10 2006/03/11 04:38:38 momjian Exp $ */
 
 #ifndef			BIG_ENDIAN
 #define			BIG_ENDIAN		4321
@@ -12,4 +11,5 @@
 #endif
 #ifndef			BYTE_ORDER
 #define			BYTE_ORDER		BIG_ENDIAN
+
 #endif
